/* CoolTran, traductor de trminos.
 * 
 * Copyright (C) 2007
 *
 * Authors: Javier Garca Palacios <jgarcia1709@gmail.com>
 *          Diego Sevillano de Miguel <sevas85@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 */

import java.awt.Color;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyAdapter;
import java.awt.event.KeyEvent;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.InputStream;
import java.io.OutputStream;
import javax.swing.JFileChooser;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;


public class Aplicacion {

	
	Configuracion config = null;
	Ventana1 controlador = null;
	Usuario UserRegis = null;
	Valoracion valora = null;
	Busqueda busqueda = null;
	Conexion conexion = null;
	Version version = null;
	boolean flagEstaConectado=false;
	String loginbd = null;
	String passbd = null;
	String urlbd = null;
	PortaPapeles clipboard;
	String indiceColaborativo="0";				//indice del colaborativo seleccionado
	String[] diccionariosColaborativos;			//diccionarios colaborativos: "esp-eng"
	String[] nombresDiccionariosColaborativos;	//nombres de los dic colab: "wiki ESP-ENG"
	String[] diccionariosLocales;				//diccionarios locales: "ESP-ENG"
	String tipoDiccionarioSeleccionado="Local"; //por defecto y al principio esta en Local
	String dicColabSeleccionado;
	boolean flagFinConfigColaborativo=false;	//bandera que indica que se a terminado de aplicar la configuracion 
	boolean flagTrayDisponible=false;
	boolean flagtrayCreado=false;
	boolean flagClipboardHabilitado=false;
	boolean flagSplashDisponible=false;
	Tray tray=null;

	
	public Aplicacion (){ 
		
		Splash splashinicio =null;	
		String SO=null;
		
		SO=System.getProperty("os.name");
		
		if (SO.toLowerCase().contains("windows")){	//Porque de momento el Tray solo funciona en windows
			flagTrayDisponible=true;
		}
			
		config =new Configuracion();		//se carga la configuracin
		controlador = new Ventana1(); 		//se crea y pinta la ventana
		
		if(Boolean.parseBoolean(Configuracion.propiedades.getProperty("splash"))){
			flagSplashDisponible=true;
			splashinicio = new Splash("imagenes/splash.png",controlador,15000); //Creamos el Splash	
		}else{
			controlador.setVisible(true);
		}
		
		aplicarConfiguracion();				//se aplica la configuracin cargada previamente
		clipboard = new PortaPapeles();		//se lanza el capturador de el clipboard del sistema
		eventos();							//se lanza en control de eventos sobre la ventana
		
		//radio buttons de busqueda con OCR, desabilitados de momento
		controlador.jLabel1.setVisible(false);
		controlador.jLabel8.setVisible(false);
		controlador.jLabel9.setVisible(false);
		controlador.jLabel10.setVisible(false);
		controlador.jLabel11.setVisible(false);
		controlador.jLabel12.setVisible(false);
		controlador.jCheckBox1.setVisible(false);
		controlador.jCheckBox2.setVisible(false);
		controlador.jCheckBox3.setVisible(false);
		controlador.jCheckBox4.setVisible(false);
		controlador.jCheckBox5.setVisible(false);
		//---
		
		loginbd = Configuracion.propiedades.getProperty("loginbd");
		passbd = Configuracion.propiedades.getProperty("passbd");
		urlbd = Configuracion.propiedades.getProperty("urlbd");

		if (Boolean.parseBoolean(Configuracion.propiedades.getProperty("dispConexion"))==true){
			controlador.jLabel5.setText(Configuracion.messages.getString("msj_conectando"));
			conexion = new Conexion(loginbd,passbd,urlbd);		//se crea la conexin con la base de datos
			try{
				conexion.conectar(); //falta poner timeout en conexion
				if (conexion.isConectado()){
					flagEstaConectado=true;
					//creamos los colaborativos
					config.cargarColaborativo(conexion);	
					aplicarConfiguracionColab();
					controlador.jComboBox4.addItem(Configuracion.messages.getString("combo_colaborativo"));
					if ((Configuracion.propiedades.getProperty("tipoDic")).equals("Colaborativo")){
						setTipoDiccionarioSeleccionado("Colaborativo");
						controlador.jComboBox4.setSelectedItem(Configuracion.messages.getString("combo_colaborativo"));
						controlador.jLabelDiccionario.setText(nombresDiccionariosColaborativos[Integer.valueOf(indiceColaborativo)]);
					}
					controlador.jLabel5.setText(Configuracion.messages.getString("msj_conectado"));
					controlador.jTextPane4.setText("");
					flagFinConfigColaborativo=true;
					
					//Comprobamos la  version de nuestro sistema 				
					version = new Version(SO,conexion);
					if(version.comprobarVersion()){					
						controlador.jLabel5.setText("Nueva Versin "+version.getNombre());					
					}
				}
			 }catch(Exception conexion){
		    	System.out.println(conexion);
		    	controlador.jLabel5.setText(Configuracion.messages.getString("msj_errorconexion"));
				if(flagSplashDisponible){
					splashinicio.setVisible(false);
					controlador.setVisible(true);
				}
				controlador.jTextField.requestFocusInWindow();
		     }
		}
		if(flagSplashDisponible){
			splashinicio.setVisible(false);
			controlador.setVisible(true);
		}
		controlador.jTextField.requestFocusInWindow();
		
		
		
		if (flagTrayDisponible){
			creaTray();
		}
	}//Aplicacion

	
	private void creaTray(){
		tray = new Tray(this);			//se crea el tray icon
		tray.setTipoDicTray("Local"); 	//por defecto se selecciona el diccionario Local
		tray.setDiccLocalesTray(config.dicc_install.length, diccionariosLocales,Configuracion.propiedades.getProperty("dicLocDefault"));
		if (Boolean.parseBoolean(Configuracion.propiedades.getProperty("dispConexion"))==true){
			if (flagEstaConectado){
				if ((Configuracion.propiedades.getProperty("tipoDic")).equals("Colaborativo")){
					tray.setTipoDicTray("Colaborativo"); //si se cumple todo lo anterior
				}
				tray.setDiccColaborativosTray(config.colab_install.size(), nombresDiccionariosColaborativos,Integer.valueOf(Configuracion.propiedades.getProperty("indiceColaborativo")));
			}
		}
		tray.setConfiguracionTray();		//se aplica la configuracin de tray
		if (Boolean.parseBoolean(Configuracion.propiedades.getProperty("dispConexion"))==false){
			tray.rbMenuItemColaborativo.setEnabled(false);
			tray.submenuColaborativo.setEnabled(false);
		}
		flagtrayCreado=true;
	}
	
	
	/*******************************************************************
	 * 
	 *						APLICARCONFIGURACION
	 * 
	 *********************************************************************/		
	
	private void aplicarConfiguracion(){
		
		diccionariosLocales= new String[config.dicc_install.length];
		
		
		for (int i = 0; i < config.dicc_install.length; i++) {	
			diccionariosLocales[i]=String.valueOf(config.dicc_install[i].substring(13,20));
			controlador.jComboBox3.addItem(config.dicc_install[i].substring(13,20));
		}	
		
		for (int i = 0; i < config.valoracion.length; i++) {
			controlador.jComboBox.addItem(config.valoracion[i]);
		}
			
		for (int i = 0; i < config.idioma.length; i++) {
			controlador.jComboBox1.addItem(config.idioma[i]);
		}

		controlador.jComboBox4.setSelectedIndex(0);
		controlador.jLabel3.setVisible(false);
		controlador.jLabelvalorar.setVisible(false);
		controlador.jComboBox.setVisible(false);
		controlador.jComboBoxvalorar.setVisible(false);

		controlador.jCheckBox6.setSelected(Boolean.parseBoolean(Configuracion.propiedades.getProperty("dispConexion")));
		controlador.jComboBox1.setSelectedIndex(Integer.valueOf(Configuracion.propiedades.getProperty("idiDefault")));
		controlador.jComboBox3.setSelectedItem(String.valueOf(Configuracion.propiedades.getProperty("dicLocDefault")));

		controlador.jCheckBox1.setSelected(Boolean.parseBoolean(Configuracion.propiedades.getProperty("tCtrl")));
		controlador.jCheckBox2.setSelected(Boolean.parseBoolean(Configuracion.propiedades.getProperty("tAlt")));
		controlador.jCheckBox3.setSelected(Boolean.parseBoolean(Configuracion.propiedades.getProperty("tMays")));
		controlador.jCheckBox4.setSelected(Boolean.parseBoolean(Configuracion.propiedades.getProperty("clicI")));
		controlador.jCheckBox5.setSelected(Boolean.parseBoolean(Configuracion.propiedades.getProperty("clicD")));
		
		controlador.jCheckBoxSplash.setSelected(Boolean.parseBoolean(Configuracion.propiedades.getProperty("splash")));
		
		
		if (Boolean.parseBoolean(Configuracion.propiedades.getProperty("dispConexion"))==false){
			controlador.jLabel19.setForeground(Color.lightGray);
			controlador.jComboBox51.setEnabled(false);
			controlador.jComboBox4.removeItem(Configuracion.messages.getString("combo_colaborativo"));
			controlador.jLabel3.setVisible(false);
			controlador.jLabelvalorar.setVisible(false);
			controlador.jComboBox.setVisible(false);
			controlador.jComboBoxvalorar.setVisible(false);
		}
		
	}//aplicarConfiguracion
	
	/*******************************************************************
	 * 
	 *					APLICARCONFIGURACIONCOLAB
	 * 
	 *********************************************************************/	
	
	private void aplicarConfiguracionColab(){

		//cargamos los nombres en la base de datos de los diccionarios colaborativos: "esp-eng"
		diccionariosColaborativos = new String[config.colab_tabla.size()];
		for (int i = 0; i < config.colab_install.size(); i++) {
			diccionariosColaborativos[i]=String.valueOf(config.colab_tabla.get(i));
		}
		//cargamos los nombres en la aplicacion de los diccionarios colaborativos: "wiki ESP-ENG"
		nombresDiccionariosColaborativos= new String[config.colab_install.size()];	
		for (int i = 0; i < config.colab_install.size(); i++) {
			nombresDiccionariosColaborativos[i]=String.valueOf(config.colab_install.get(i));
			controlador.jComboBox51.addItem(config.colab_install.get(i));
			controlador.jChoiceColab.addItem(config.colab_install.get(i));
		
			
			
		}	
		indiceColaborativo=Configuracion.propiedades.getProperty("indiceColaborativo");
		controlador.jComboBox51.setSelectedItem(String.valueOf(Configuracion.propiedades.getProperty("dicColDefault")));

		
       //////COLABORATIVO
	    
	    controlador.jComboBox51.addActionListener(new ActionListener(){
			public void actionPerformed(ActionEvent e) {
				indiceColaborativo=String.valueOf(controlador.jComboBox51.getSelectedIndex());
				config.cambiaDicColab(String.valueOf(controlador.jComboBox51.getSelectedItem()));
				config.cambiaIndiceColab(String.valueOf(controlador.jComboBox51.getSelectedIndex()));
				if (tipoDiccionarioSeleccionado.equals("Colaborativo")){
					controlador.jLabelDiccionario.setText(nombresDiccionariosColaborativos[Integer.valueOf(indiceColaborativo)]);
				}
				//cambia diccionario tb en tray (si esta en windows claro)
				if (flagTrayDisponible){
					tray.tray.removeTrayIcon(tray.ti);
					creaTray();
				}
				if (!controlador.jTextField.getText().equals(""))
					buscarTermino(controlador.jTextField.getText());
				
			}	
	    });
	   
	    
	    //CARGA DE USUARIO
	    
	    if (Configuracion.propiedades.containsKey("usuario") && Configuracion.propiedades.containsKey("password")){
	    	
			UserRegis = new Usuario(Configuracion.propiedades.getProperty("usuario"),Configuracion.propiedades.getProperty("password"),controlador,conexion);
			if ( UserRegis.identificarse() ){
					controlador.panelRegistrar.setVisible(false);
					controlador.panelAnadir.setVisible(true);
					aplicarConfiguracionAnadir();
			}else{

			}
	    	
	    }else{
	    	controlador.jLabel40.setText(Configuracion.messages.getString("msj_primeravez"));
	    }
	    
	    
	    ///desplegable valoracion
	    	    
	    controlador.jComboBox.addActionListener(new ActionListener() {
			
			public void actionPerformed(ActionEvent arg0) {
				// TODO Auto-generated method stub
				
				if (busqueda!=null){	
					String numter = (String) busqueda.numTermino.get(controlador.jComboBoxvalorar.getSelectedIndex());
					String tabla = getDicColabSeleccionado();
					String tipo = String.valueOf(controlador.jComboBox.getSelectedIndex());
					valora = new Valoracion(tabla,numter,tipo ,conexion);
					valora.valorarTermino();
					if (valora.isValorado()){
						controlador.jLabel5.setText(Configuracion.messages.getString("msj_valoracion"));
					}else{
						controlador.jLabel5.setText(Configuracion.messages.getString("msj_errorvaloracion"));
					}
				}
				
			}
		});
	    
	
	}//aplicarConfiguracionColab
	
	
	private void aplicarConfiguracionAnadir(){
		
		for (int i = 0; i < nombresDiccionariosColaborativos.length; i++) {
					
			//System.out.println("Ahi van " +i+ " "  + nombresDiccionariosColaborativos[i]);
		}

	}//aplicarConfiguracionAadir
	

	
	/*******************************************************************
	 * 
	 *						EVENTOS
	 * 
	 *********************************************************************/	
	
	private void eventos(){
		
		controlador.jButton.addMouseListener(new java.awt.event.MouseAdapter() {
			public void mouseClicked(java.awt.event.MouseEvent e) {
				
				buscarTermino(controlador.getPalabra());
			}		
		});
		
		controlador.jButton.addKeyListener(new KeyAdapter() {
			public void keyReleased(KeyEvent ke) {
				if (ke.getKeyCode() == KeyEvent.VK_ENTER) {
					
					buscarTermino(controlador.getPalabra());
				}
			}
		});
		
		controlador.jTextField.addKeyListener(new KeyAdapter() {
			public void keyReleased(KeyEvent ke) {
				if (ke.getKeyCode() == KeyEvent.VK_ENTER) {
					
					buscarTermino(controlador.getPalabra());
				}	
			}
		});

		
		if (flagTrayDisponible) {
			
		   controlador.addWindowListener(new java.awt.event.WindowAdapter() {    
			   public void windowActivated(java.awt.event.WindowEvent e) {
					//Activamos la busqueda por clipboard			   
					if (getFlagClipboardHabilitado()){
						controlador.jTextField.setText(clipboard.getClipboardContents());
						buscarTermino(clipboard.getClipboardContents());									
						setFlagClipboardHabilitado(false);
					}				
				}
			   
			   public void windowClosing(java.awt.event.WindowEvent e) {
					//Activamos la busqueda por clipboard
				   setFlagClipboardHabilitado(true);
				}
			   
		   });
		   
		}else{
			
			controlador.addWindowListener(new java.awt.event.WindowAdapter() {    
			   public void windowIconified(java.awt.event.WindowEvent e) {
					//Activamos la busqueda por clipboard
					flagClipboardHabilitado = true;				
				}
		    	public void windowDeiconified(java.awt.event.WindowEvent e) {	
			        if (flagClipboardHabilitado&&!(clipboard.getClipboardContents()=="")){
							controlador.jTextField.setText(clipboard.getClipboardContents());
							buscarTermino(clipboard.getClipboardContents());				
			        }
				}
		    });
		
		}
 
		
		//Toolkit.getDefaultToolkit().addAWTEventListener(listener, eventMask)
		
		controlador.jButton1.addMouseListener(new java.awt.event.MouseAdapter() {
			public void mouseClicked(java.awt.event.MouseEvent e) {
				Configuracion.propiedades.setProperty("colorprima1", "102");
				Configuracion.propiedades.setProperty("colorprima2", "174");
				Configuracion.propiedades.setProperty("colorprima3", "233");
				Configuracion.propiedades.setProperty("colorsecun1", "66");
				Configuracion.propiedades.setProperty("colorsecun2", "129");
				Configuracion.propiedades.setProperty("colorsecun3", "183");
				controlador.cambiarColor();
				config.guardarconfiguracion();
			}
		});
		
		controlador.jButton11.addMouseListener(new java.awt.event.MouseAdapter() {
			public void mouseClicked(java.awt.event.MouseEvent e) {
				JFileChooser fileChooser = new JFileChooser();
				//Creamos el filtro para ver solo archivos .java
				fileChooser.setFileFilter(new javax.swing.filechooser.FileFilter ()
				{
				//Esta funcion es la que mostrara los archivos
				//con la extension que quieres y los directorios
				public boolean accept (File file)
				{
				String filename = file.getName();
				return (filename.endsWith(".properties") || file.isDirectory());
				}
				//Esta funcion muestra el texto en la lista de opciones de ficheros para ver
				public String getDescription()
				{
				return "Archivos de diccionario (*.properties)";
				}
				});
				int seleccion = fileChooser.showOpenDialog(controlador);
				if (seleccion == JFileChooser.APPROVE_OPTION)
				{
				   File fichero = fileChooser.getSelectedFile();
				   // y a trabajar con fichero ....
				   File dst = new File("diccionarios/"+fichero.getName());
				   
				   try{ 
			       InputStream in = new FileInputStream(fichero);
			       OutputStream out = new FileOutputStream(dst);
			       
			       //Algoritmo de copia de ficheros
			       byte[] buf = new byte[1024];
			       int len;
			       while ((len = in.read(buf)) > 0) {
			           out.write(buf, 0, len);
			       }
			       in.close();
			       out.close(); 
			       //fin copia
			       
			       }catch(Exception ex){
			    	   System.out.println(e);
			       }
				}
			}		
		});
		
		
		controlador.jComboBox1.addActionListener(new ActionListener(){
			public void actionPerformed(ActionEvent e) {
				config.cambiaridioma(String.valueOf(controlador.jComboBox1.getSelectedIndex()));
				controlador.cambiarIdioma(flagEstaConectado);
				//cambia idioma tb en tray (si esta en windows claro)
				if (flagTrayDisponible){
					tray.tray.removeTrayIcon(tray.ti);
					creaTray();
				}
			}
		});
		
	    controlador.jComboBox3.addActionListener(new ActionListener(){
			public void actionPerformed(ActionEvent e) {
				config.cambiarDiccionario(String.valueOf(controlador.jComboBox3.getSelectedItem()));
				if (tipoDiccionarioSeleccionado.equals("Local")){
					controlador.jLabelDiccionario.setText(Configuracion.propiedades.getProperty("dicLocDefault"));
				}
				//cambia diccionario tb en tray (si esta en windows claro)
				if (flagTrayDisponible){
					tray.tray.removeTrayIcon(tray.ti);
					creaTray();
				}
				if (!controlador.jTextField.getText().equals(""))
					buscarTermino(controlador.jTextField.getText());
			}	
	    });

	    		
	    controlador.jComboBox4.addActionListener(new ActionListener(){
			public void actionPerformed(ActionEvent e) {
				if(String.valueOf(controlador.jComboBox4.getSelectedItem()).equals(Configuracion.messages.getString("combo_local"))){
					config.cambiaTipoDic("Local");
					setTipoDiccionarioSeleccionado("Local");
					controlador.jLabel3.setVisible(false);
					controlador.jComboBox.setVisible(false);
					controlador.jComboBoxvalorar.setVisible(false);
					controlador.jLabelvalorar.setVisible(false);
					controlador.jLabelDiccionario.setText(Configuracion.propiedades.getProperty("dicLocDefault"));
				}else{
					config.cambiaTipoDic("Colaborativo");
					setTipoDiccionarioSeleccionado("Colaborativo");
					controlador.jLabel3.setVisible(true);
					controlador.jComboBox.setVisible(true);
					controlador.jComboBoxvalorar.setVisible(true);
					controlador.jLabelvalorar.setVisible(true);
					controlador.jLabelDiccionario.setText(nombresDiccionariosColaborativos[Integer.valueOf(indiceColaborativo)]);
				}
				//cambia tipo dic tb en tray (si esta en windows claro)
				if (flagTrayDisponible){
					if(flagtrayCreado){
						tray.tray.removeTrayIcon(tray.ti);
						creaTray();
					}
				}
			}	
	    });

	    
	    
	    
	    controlador.jCheckBox6.addActionListener(new ActionListener(){
			public void actionPerformed(ActionEvent e) {
				config.cambiaConexion(String.valueOf(controlador.jCheckBox6.isSelected()));
				if (Boolean.parseBoolean(Configuracion.propiedades.getProperty("dispConexion"))==false){
					controlador.jLabel19.setForeground(Color.lightGray);
					controlador.jComboBox51.setEnabled(false);
					controlador.jComboBox4.removeItem(Configuracion.messages.getString("combo_colaborativo"));
					controlador.jLabel5.setText("Cooltran");
				}else{
					//conecta con la base de datos si no estaba conectado
					if(!flagEstaConectado){
						controlador.jLabel5.setText(Configuracion.messages.getString("msj_conectando"));
						conexion = new Conexion(loginbd,passbd,urlbd);		//se crea la conexin con la base de datos
						try{
							conexion.conectar();
							if (conexion.isConectado()){
								flagEstaConectado=true;
								//creamos los colaborativos
								config.cargarColaborativo(conexion);	
								aplicarConfiguracionColab();
								controlador.jComboBox4.addItem(Configuracion.messages.getString("combo_colaborativo"));
								setTipoDiccionarioSeleccionado("Colaborativo");
								controlador.jComboBox4.setSelectedItem(Configuracion.messages.getString("combo_colaborativo"));
								controlador.jLabelDiccionario.setText(nombresDiccionariosColaborativos[Integer.valueOf(indiceColaborativo)]);
								controlador.jLabel5.setText(Configuracion.messages.getString("msj_conectado"));
								controlador.jTextPane4.setText("");
								flagFinConfigColaborativo=true;
								
								
								
							}
						 }catch(Exception conexion){
					    	System.out.println(conexion);
					    	controlador.jLabel5.setText(Configuracion.messages.getString("msj_errorconexion"));
					     }
					}else{ //si ya estaba conectado solo tiene q aadir lo que quit
						controlador.jComboBox4.addItem(Configuracion.messages.getString("combo_colaborativo"));
						setTipoDiccionarioSeleccionado("Colaborativo");
						controlador.jComboBox4.setSelectedItem(Configuracion.messages.getString("combo_colaborativo"));
						controlador.jLabelDiccionario.setText(nombresDiccionariosColaborativos[Integer.valueOf(indiceColaborativo)]);
						controlador.jLabel5.setText(Configuracion.messages.getString("msj_conectado"));
					}
					//----------
					controlador.jLabel19.setForeground(Color.white);
					controlador.jComboBox51.setEnabled(true);
				}
				//cambia tb en tray (si esta en windows claro)
				if (flagTrayDisponible){
					if(flagtrayCreado){
						tray.tray.removeTrayIcon(tray.ti);
						creaTray();
					}
				}
								
			}	
	    });
	    
	    controlador.jCheckBoxSplash.addActionListener(new ActionListener(){
			public void actionPerformed(ActionEvent e) {
				config.cambiaSplash(String.valueOf(controlador.jCheckBoxSplash.isSelected()));		
			}	
	    });
	    
	    controlador.jCheckBox1.addActionListener(new ActionListener(){
			public void actionPerformed(ActionEvent e) {
				config.cambiaTeclas("tCtrl",String.valueOf(controlador.jCheckBox1.isSelected()));
				config.cambiaTeclas("tAlt",String.valueOf(controlador.jCheckBox2.isSelected()));
				config.cambiaTeclas("tMays",String.valueOf(controlador.jCheckBox3.isSelected()));	
			}	
	    });
	    
	    controlador.jCheckBox2.addActionListener(new ActionListener(){
			public void actionPerformed(ActionEvent e) {
				config.cambiaTeclas("tCtrl",String.valueOf(controlador.jCheckBox1.isSelected()));
				config.cambiaTeclas("tAlt",String.valueOf(controlador.jCheckBox2.isSelected()));
				config.cambiaTeclas("tMays",String.valueOf(controlador.jCheckBox3.isSelected()));		
			}	
	    });
	    
	    controlador.jCheckBox3.addActionListener(new ActionListener(){
			public void actionPerformed(ActionEvent e) {
				config.cambiaTeclas("tCtrl",String.valueOf(controlador.jCheckBox1.isSelected()));
				config.cambiaTeclas("tAlt",String.valueOf(controlador.jCheckBox2.isSelected()));
				config.cambiaTeclas("tMays",String.valueOf(controlador.jCheckBox3.isSelected()));
			}	
	    });
	    
	    controlador.jCheckBox4.addActionListener(new ActionListener(){
			public void actionPerformed(ActionEvent e) {
				config.cambiaTeclas("clicI",String.valueOf(controlador.jCheckBox4.isSelected()));
				config.cambiaTeclas("clicD",String.valueOf(controlador.jCheckBox5.isSelected()));		
			}	
	    });
	    
	    controlador.jCheckBox5.addActionListener(new ActionListener(){
			public void actionPerformed(ActionEvent e) {
				config.cambiaTeclas("clicD",String.valueOf(controlador.jCheckBox5.isSelected()));
				config.cambiaTeclas("clicI",String.valueOf(controlador.jCheckBox4.isSelected()));
			}	
	    });
	    
	    /////////////EVENTOS ////////////CAMBIO COLOR INTERFAZ/////////////
	        
	   controlador.jSlider.addChangeListener(new ChangeListener() {

		public void stateChanged(ChangeEvent arg0) {
			Configuracion.propiedades.setProperty("colorprima1", String.valueOf(controlador.jSlider.getValue()));
			controlador.cambiarColor();
		
			config.guardarconfiguracion();
	
		}
   
	   }); 
	   
	   controlador.jSlider2.addChangeListener(new ChangeListener() {

			public void stateChanged(ChangeEvent arg0) {

				Configuracion.propiedades.setProperty("colorprima2", String.valueOf(controlador.jSlider2.getValue()));
				controlador.cambiarColor();
				
				config.guardarconfiguracion();
		
			}
	   
		   }); 
	   controlador.jSlider3.addChangeListener(new ChangeListener() {

			public void stateChanged(ChangeEvent arg0) {
				Configuracion.propiedades.setProperty("colorprima3", String.valueOf(controlador.jSlider3.getValue()));
				controlador.cambiarColor();
				
				config.guardarconfiguracion();
		
			}
	   
		   }); 
	   controlador.jSlider4.addChangeListener(new ChangeListener() {

			public void stateChanged(ChangeEvent arg0) {
				Configuracion.propiedades.setProperty("colorsecun1", String.valueOf(controlador.jSlider4.getValue()));
				controlador.cambiarColor();
				
				config.guardarconfiguracion();
		
			}
	   
		   }); 
	   controlador.jSlider5.addChangeListener(new ChangeListener() {

			public void stateChanged(ChangeEvent arg0) {
				Configuracion.propiedades.setProperty("colorsecun2", String.valueOf(controlador.jSlider5.getValue()));
				controlador.cambiarColor();
				
				config.guardarconfiguracion();			
		
			}
	   
		   }); 
	   controlador.jSlider6.addChangeListener(new ChangeListener() {

			public void stateChanged(ChangeEvent arg0) {
				Configuracion.propiedades.setProperty("colorsecun3", String.valueOf(controlador.jSlider6.getValue()));
				controlador.cambiarColor();
			
				config.guardarconfiguracion();
		
			}
	   
		   }); 
	   
	   /////CONEXION///////
	   
	   
	   controlador.jButton40.addMouseListener(new java.awt.event.MouseAdapter() {
			public void mouseClicked(java.awt.event.MouseEvent e) {
				if(flagEstaConectado){
					UserRegis = new Usuario(controlador.jTextField40.getText(),String.valueOf(controlador.jPasswordField.getPassword()),controlador,conexion);
					if ( UserRegis.identificarse() ){
						config.guardarconfiguracion();
						aplicarConfiguracionAnadir();
						controlador.panelRegistrar.setVisible(false);
						controlador.panelAnadir.setVisible(true);
						controlador.jTextField50.requestFocusInWindow();
					}else{			
						System.out.println("No ha identificado");
					}
				}else{
					//mostrar mensaje de que no hay conexin
				}
			}		
		});
	   
	   controlador.jButton40.addKeyListener(new KeyAdapter() {
			public void keyReleased(KeyEvent ke) {
				if (ke.getKeyCode() == KeyEvent.VK_ENTER) {
					if(flagEstaConectado){
						UserRegis = new Usuario(controlador.jTextField40.getText(),String.valueOf(controlador.jPasswordField.getPassword()),controlador,conexion);
						if ( UserRegis.identificarse() ){
							config.guardarconfiguracion();
							aplicarConfiguracionAnadir();
							controlador.panelRegistrar.setVisible(false);
							controlador.panelAnadir.setVisible(true);
							controlador.jTextField50.requestFocusInWindow();
						}else{			
							System.out.println("No ha identificado");
						}
					}else{
						//mostrar mensaje de que no hay conexin
					}
				}
			}
		});
	   
	   controlador.jPasswordField.addKeyListener(new KeyAdapter() {
			public void keyReleased(KeyEvent ke) {
				if (ke.getKeyCode() == KeyEvent.VK_ENTER) {
					if(flagEstaConectado){
						UserRegis = new Usuario(controlador.jTextField40.getText(),String.valueOf(controlador.jPasswordField.getPassword()),controlador,conexion);
						if ( UserRegis.identificarse() ){
							config.guardarconfiguracion();
							aplicarConfiguracionAnadir();
							controlador.panelRegistrar.setVisible(false);
							controlador.panelAnadir.setVisible(true);
							controlador.jTextField50.requestFocusInWindow();
						}else{			
							System.out.println("No ha identificado");
						}
					}else{
						//mostrar mensaje de que no hay conexin
					}
				}
			}
		});
	   
	   //Salir de Aadir Termino
	   
	   controlador.jButtonLogout.addMouseListener(new java.awt.event.MouseAdapter() {
			public void mouseClicked(java.awt.event.MouseEvent e) {
			    	controlador.jTextField40.setEditable(true);
			    	controlador.jPasswordField.setEditable(true);
					controlador.jTextField40.setText("");
					controlador.jPasswordField.setText("");
					controlador.jLabel40.setText("");
					controlador.jLabelCorreo.setVisible(false);
					controlador.jLabelSo.setVisible(false);
					controlador.jTextCorreo.setVisible(false);
					controlador.jTextSo.setVisible(false);
					controlador.jButtonLogout2.setVisible(false);
					controlador.panelRegistrar.setVisible(true);
					controlador.panelAnadir.setVisible(false);
					
			}		
		});
	   
	   //Salir de Registrar
	   
	   controlador.jButtonLogout2.addMouseListener(new java.awt.event.MouseAdapter() {
			public void mouseClicked(java.awt.event.MouseEvent e) {
				    controlador.jTextField40.setEditable(true);
					controlador.jPasswordField.setEditable(true);
					controlador.jTextField40.setText("");
					controlador.jPasswordField.setText("");
					controlador.jLabel40.setText("");
					controlador.jLabelCorreo.setVisible(false);
					controlador.jLabelSo.setVisible(false);
					controlador.jTextCorreo.setVisible(false);
					controlador.jTextSo.setVisible(false);
					controlador.jButtonLogout2.setVisible(false);
					controlador.panelRegistrar.setVisible(true);
					controlador.panelAnadir.setVisible(false);
			}		
		});
	   
	   
	   controlador.jButton50.addMouseListener(new java.awt.event.MouseAdapter() {
		
			public void mouseClicked(java.awt.event.MouseEvent e) {
				String radio = controlador.radioSeleccionado();
				String wtabla = diccionariosColaborativos[controlador.jChoiceColab.getSelectedIndex()];
				
				if ( UserRegis.anadirTermino(wtabla,radio  ) ){
					System.out.println("Se ha introducido un termino");
					controlador.limpiarTermino();
				}else{
					System.out.println("no Se ha introducido un termino");
				}			
			}		
		});
	 
		
	}//eventos
	
	
	
	private void buscarTermino(String termino){
		busqueda = new Busqueda();
		
		controlador.jLabel5.setText("");

		if (tipoDiccionarioSeleccionado.equals("Colaborativo")&& flagFinConfigColaborativo){
			dicColabSeleccionado = getDicColabSeleccionado();
			controlador.setTraduccion(busqueda.traducirColaborativo(termino,dicColabSeleccionado,conexion));				
			controlador.jComboBoxvalorar.removeAllItems();
			for (int i = 0; i < busqueda.getNumeroPalabras(); i++) {
				controlador.jComboBoxvalorar.addItem(String.valueOf(i+1));
			}
		}else{
			controlador.setTraduccion(busqueda.traducirLocal(termino));
		}
		
		//try {
			//controlador.jTextPane.setPage("http://www.google.com/pda/search?mrestrict=xhtml&q="+termino);
			//controlador.jTextPane2.setPage("http://www.google.com/gwt/n?u=http%3A%2F%2Fwww.wordreference.com%2Fes%2Fen%2Ftranslation.asp%3Fspen%3D"+termino+"&_gwt_noimg=1");
		//}catch (IOException e) {
		//	e.printStackTrace();
		//}
		
	}
	
	private String getDicColabSeleccionado(){

		if (flagEstaConectado){	
			return diccionariosColaborativos[Integer.valueOf(indiceColaborativo)];
		}else{
			return ""; //se puede quitar ya
		}
	}
	
	public void setTipoDiccionarioSeleccionado(String tipo){
		tipoDiccionarioSeleccionado=tipo;
	}
	
	public void setFlagClipboardHabilitado(boolean valor){
		flagClipboardHabilitado=valor;
	}
	
	public boolean getFlagClipboardHabilitado(){
		return flagClipboardHabilitado;
	}
	
	
	
	
	/*******************************************************************
	 *						        MAIN
	 *********************************************************************/	
	
	public static void main(String[] args) {
		
		new Aplicacion();
		
	}
	
}//aplicacion


